![logo](https://jeodpp.jrc.ec.europa.eu/services/shared/pngs/vois.png)

Python library to simplify the creation of impactful Voilà dashboards.

The online documentation for the vois library is available [here](https://vois.readthedocs.io/en/latest/1_intro.html)

The PDF documentation for the vois library is available [here](https://vois.readthedocs.io/_/downloads/en/latest/pdf/)

The vois library contains:

folder **vois**: helper functions for tasks not directly related to ipyvuetify (manage geojson files, create an interactive map to display custom geojson, simplify visualization of hierarchical data in Plotly, create custom SVG visualizations, etc.)

folder **vois/vuetify**: classes to simplify the development of GUIs using ipyvuetify (each source file contains a wrapper to simplify the usage of a ipyvuetify widget)


## License

VOIS library is released under a
[EUPL Version 1.2](https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12) license.


## Tutorial

The tutorial section of the documentation available [here](https://vois.readthedocs.io/en/latest/2_tutorial.html) provides a step by step example for the construction of a dashboard to display EUROSTAT data on Energy Consumption in Europe.

![screenshot](https://jeodpp.jrc.ec.europa.eu/services/shared/pngs/vois_example.png)